@@ -1,6 +1,6 @@
 import sys
 import argparse
-from alto.commands import terra, upload, parse_monitoring_log, cromwell
+from alto.commands import terra, upload, parse_monitoring_log, cromwell, query
 
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -12,10 +12,10 @@ except ImportError:  # < Python 3.8: Use backport module
     from importlib_metadata import version
 
 def main():
-    str2module = {'terra': terra, 'upload': upload, 'parse_monitoring_log': parse_monitoring_log, 'cromwell': cromwell}
+    str2module = {'terra': terra, 'upload': upload, 'parse_monitoring_log': parse_monitoring_log, 'cromwell': cromwell, 'query': query}
 
     parser = argparse.ArgumentParser(description='Run an altocumulus command.')
-    parser.add_argument('command', help='The command', choices=['terra', 'upload', 'parse_monitoring_log', 'cromwell'])
+    parser.add_argument('command', help='The command', choices=['terra', 'upload', 'parse_monitoring_log', 'cromwell', 'query'])
     parser.add_argument('command_args', help='The command arguments', nargs=argparse.REMAINDER)
     parser.add_argument('-v', '--version', action="version", version=version('altocumulus'))
     my_args = parser.parse_args()
